@@ -1,14 +1,12 @@
 import colorsys
 import io
 from time import process_time
-from typing import Any
 
 from rich import box
 from rich.color import Color
 from rich.console import (
     Console,
     ConsoleOptions,
-    ConsoleRenderable,
     Group,
     RenderResult,
     RenderableType,
@@ -197,7 +195,7 @@ def iter_last(values: Iterable[T]) -> Iterable[Tuple[bool, T]]:
     markdown_example = """\
 # Markdown
 
-Supports much of the *markdown*, __syntax__!
+Supports much of the *markdown* __syntax__!
 
 - Headers
 - Basic formatting: **bold**, *italic*, `code`
